==> dynamodb-keyspace-0.0.6.tgz: package/dist-es/command/Query.js <==
import { QueryCommand } from '@aws-sdk/lib-dynamodb';
import { DkCommand } from './Command';
import { lowerCaseKeys, upperCaseKeys } from '../util/keyCapitalize';
import { applyDefaults } from '../util/defaults';
import { executeMiddlewares, executeMiddleware } from '../Middleware';
export var DkQueryItemsSort;
(function (DkQueryItemsSort) {
    DkQueryItemsSort["ASCENDING"] = "ascending";
    DkQueryItemsSort["DESCENDING"] = "descending";
})(DkQueryItemsSort || (DkQueryItemsSort = {}));
const QUERY_COMMAND_INPUT_DATA_TYPE = 'QueryCommandInput';
const QUERY_COMMAND_INPUT_HOOK = ['CommandInput', 'ReadCommandInput', QUERY_COMMAND_INPUT_DATA_TYPE];
const QUERY_COMMAND_OUTPUT_DATA_TYPE = 'QueryCommandOutput';
const QUERY_COMMAND_OUTPUT_HOOK = ['CommandOutput', 'ReadCommandOutput', QUERY_COMMAND_OUTPUT_DATA_TYPE];
export class DkQueryCommand extends DkCommand {
    constructor(input) {
        super(input);
        this.inputMiddlewareConfig = { dataType: QUERY_COMMAND_INPUT_DATA_TYPE, hooks: QUERY_COMMAND_INPUT_HOOK };
        this.outputMiddlewareConfig = { dataType: QUERY_COMMAND_OUTPUT_DATA_TYPE, hooks: QUERY_COMMAND_OUTPUT_HOOK };
        this.handleInput = async ({ defaults, middleware }) => {
            const postDefaultsInput = applyDefaults(this.input, defaults, ['returnConsumedCapacity']);
            const { data: postMiddlewareInput } = await executeMiddlewares([...this.inputMiddlewareConfig.hooks], {
                dataType: this.inputMiddlewareConfig.dataType,
                data: postDefaultsInput
            }, middleware);
            const { cursorKey, index, sort = DkQueryItemsSort.ASCENDING, ...rest } = postMiddlewareInput;
            const formattedInput = {
                exclusiveStartKey: cursorKey,
                indexName: index,
                scanIndexForward: sort === DkQueryItemsSort.ASCENDING ? true : false,
                ...rest
            };
            const upperCaseInput = upperCaseKeys(formattedInput);
            return upperCaseInput;
        };
        this.handleOutput = async (output, { middleware }) => {
            const lowerCaseOutput = lowerCaseKeys(output);
            const items = (output.Items || []);
            const cursorKey = output.LastEvaluatedKey;
            const formattedOutput = {
                ...lowerCaseOutput,
                items,
                cursorKey
            };
            const { data: postMiddlewareOutput } = await executeMiddlewares([...this.outputMiddlewareConfig.hooks], {
                dataType: this.outputMiddlewareConfig.dataType,
                data: formattedOutput
            }, middleware);
            if (postMiddlewareOutput.consumedCapacity)
                await executeMiddleware('ConsumedCapacity', { dataType: 'ConsumedCapacity', data: postMiddlewareOutput.consumedCapacity }, middleware);
            return postMiddlewareOutput;
        };
        this.send = async (clientConfig) => {
            const input = await this.handleInput(clientConfig);
            const output = await clientConfig.client.send(new QueryCommand(input));
            return this.handleOutput(output, clientConfig);
        };
    }
}

==> dynamodb-keyspace-0.0.7.tgz: package/dist-es/command/Query.js <==
import { QueryCommand } from '@aws-sdk/lib-dynamodb';
import { DkCommand } from './Command';
import { uncapitalizeKeys, capitalizeKeys } from 'object-key-casing';
import { applyDefaults } from '../util/defaults';
import { executeMiddlewares, executeMiddleware } from '../Middleware';
export var DkQueryItemsSort;
(function (DkQueryItemsSort) {
    DkQueryItemsSort["ASCENDING"] = "ascending";
    DkQueryItemsSort["DESCENDING"] = "descending";
})(DkQueryItemsSort || (DkQueryItemsSort = {}));
const QUERY_COMMAND_INPUT_DATA_TYPE = 'QueryCommandInput';
const QUERY_COMMAND_INPUT_HOOK = ['CommandInput', 'ReadCommandInput', QUERY_COMMAND_INPUT_DATA_TYPE];
const QUERY_COMMAND_OUTPUT_DATA_TYPE = 'QueryCommandOutput';
const QUERY_COMMAND_OUTPUT_HOOK = ['CommandOutput', 'ReadCommandOutput', QUERY_COMMAND_OUTPUT_DATA_TYPE];
export class DkQueryCommand extends DkCommand {
    constructor(input) {
        super(input);
        this.inputMiddlewareConfig = { dataType: QUERY_COMMAND_INPUT_DATA_TYPE, hooks: QUERY_COMMAND_INPUT_HOOK };
        this.outputMiddlewareConfig = { dataType: QUERY_COMMAND_OUTPUT_DATA_TYPE, hooks: QUERY_COMMAND_OUTPUT_HOOK };
        this.handleInput = async ({ defaults, middleware }) => {
            const postDefaultsInput = applyDefaults(this.input, defaults, ['returnConsumedCapacity']);
            const { data: postMiddlewareInput } = await executeMiddlewares([...this.inputMiddlewareConfig.hooks], {
                dataType: this.inputMiddlewareConfig.dataType,
                data: postDefaultsInput
            }, middleware);
            const { cursorKey, index, sort = DkQueryItemsSort.ASCENDING, ...rest } = postMiddlewareInput;
            const formattedInput = {
                exclusiveStartKey: cursorKey,
                indexName: index,
                scanIndexForward: sort === DkQueryItemsSort.ASCENDING ? true : false,
                ...rest
            };
            const upperCaseInput = capitalizeKeys(formattedInput);
            return upperCaseInput;
        };
        this.handleOutput = async (output, { middleware }) => {
            const lowerCaseOutput = uncapitalizeKeys(output);
            const items = (output.Items || []);
            const cursorKey = output.LastEvaluatedKey;
            const formattedOutput = {
                ...lowerCaseOutput,
                items,
                cursorKey
            };
            const { data: postMiddlewareOutput } = await executeMiddlewares([...this.outputMiddlewareConfig.hooks], {
                dataType: this.outputMiddlewareConfig.dataType,
                data: formattedOutput
            }, middleware);
            if (postMiddlewareOutput.consumedCapacity)
                await executeMiddleware('ConsumedCapacity', { dataType: 'ConsumedCapacity', data: postMiddlewareOutput.consumedCapacity }, middleware);
            return postMiddlewareOutput;
        };
        this.send = async (clientConfig) => {
            const input = await this.handleInput(clientConfig);
            const output = await clientConfig.client.send(new QueryCommand(input));
            return this.handleOutput(output, clientConfig);
        };
    }
}
